@@ -1,85 +1,145 @@
 """Create the command line interface using the package “argparse”."""
 
-from audiorename._version import get_versions
+from ._version import get_versions
 import argparse
 import phrydy
 import tmep
 
-fields = {
-    # album
+fields: phrydy.FieldDocCollection = {
     'ar_classical_album': {
-        'description': 'ar_classical_album',
-        'category': 'ordinary',
+        'description': 'The field “work” without the movement suffix. '
+                       'For example: “Horn Concerto: I. Allegro” -> '
+                       '“Horn Concerto”',
+        'category': 'common',
+        'examples': ['Horn Concerto', 'Die Meistersinger von Nürnberg'],
+    },
+    'ar_classical_performer': {
+        'description': '“ar_performer_short” or “albumartist” without the '
+                       'composer prefix: “Beethoven; Karajan, Mutter” -> '
+                       '“Karajan, Mutter”',
+        'category': 'common',
+        'examples': ['Karajan, Mutter', 'Karajan, StaDre'],
+        'data_type': 'str',
+    },
+    'ar_classical_title': {
+        'description': 'The movement title without the parent work prefix. '
+                       'For example “Horn Concerto: I. Allegro” -> '
+                       '“I. Allegro”',
+        'category': 'common',
+        'examples': ['I. Allegro',
+                     'Akt III, Szene V. "Morgendlich leuchtend im rosigen '
+                     'Schein" (Walther, Volk, Meister, Sachs, Pogner, Eva)'],
+        'data_type': 'str',
+    },
+    'ar_classical_track': {
+        'description': 'If the title contains Roman numbers, then these are '
+                       'converted to arabic numbers with leading zeros. '
+                       'If no Roman numbers could be found, then the field '
+                       '“ar_combined_disctrack” is used.',
+        'category': 'common',
+        'examples': ['01', '4-08'],
+        'data_type': 'str',
     },
     'ar_combined_album': {
         'description': '“album” without ” (Disc X)”.',
-        'category': 'ordinary',
-    },
-    'ar_initial_album': {
-        'description': 'First character in lowercase of “ar_combined_album”.',
-        'category': 'ordinary',
-    },
-    # artist
-    'ar_initial_artist': {
-        'description': 'First character in lowercase of '
-                       '“ar_combined_artist_sort”',
-        'category': 'ordinary',
+        'category': 'common',
+        'examples': ['Headlines and Deadlines: The Hits of a-ha',
+                     'Die Meistersinger von Nürnberg'],
     },
     'ar_combined_artist': {
         'description': 'The first available value of this metatag order: '
                        '“albumartist” -> “artist” -> “albumartist_credit” '
                        '-> “artist_credit”',
-        'category': 'ordinary',
+        'category': 'common',
+        'examples': ['a-ha',
+                     'Richard Wagner; René Kollo, Helen Donath, ...'],
+        'data_type': 'str',
     },
     'ar_combined_artist_sort': {
         'description': 'The first available value of this metatag order: '
                        '“albumartist_sort” -> “artist_sort” -> '
                        '“ar_combined_artist”',
-        'category': 'ordinary',
-    },
-    # composer
-    'ar_initial_composer': {
-        'description': 'ar_initial_composer',
-        'category': 'ordinary',
+        'category': 'common',
+        'examples': ['a-ha', 'Wagner, Richard; Kollo, René, Donath, Helen...'],
+        'data_type': 'str',
     },
     'ar_combined_composer': {
-        'description': 'ar_combined_composer',
-        'category': 'ordinary',
+        'description': 'The first not empty field of this field list: '
+                       '“composer_sort”, “composer”, “ar_combined_artist”',
+        'category': 'common',
+        'examples': ['Beethoven, Ludwig-van', 'Wagner, Richard'],
+        'data_type': 'str',
     },
     'ar_combined_disctrack': {
         'description': 'Combination of disc and track in the format: '
-                       'disk-track, e.g. 1-01, 3-099',
-        'category': 'ordinary',
-    },
-    'ar_classical_performer': {
-        'description': 'ar_classical_performer',
-        'category': 'ordinary',
+                       'disk-track',
+        'category': 'common',
+        'examples': ['1-01', '3-099'],
+        'data_type': 'str',
     },
     'ar_combined_soundtrack': {
         'description': 'Boolean flag which indicates if the audio file is '
-        'a soundtrack',
-        'category': 'ordinary',
-    },
-    'ar_classical_title': {
-        'description': 'ar_classical_title',
-        'category': 'ordinary',
-    },
-    'ar_classical_track': {
-        'description': 'ar_classical_track',
-        'category': 'ordinary',
-    },
-    'ar_combined_year': {
-        'description': 'First “original_year” then “year”.',
-        'category': 'ordinary',
+                       'a soundtrack',
+        'category': 'common',
+        'examples': [True, False],
+        'data_type': 'bool',
     },
     'ar_combined_work_top': {
         'description': 'The work on the top level of a work hierarchy.',
-        'category': 'ordinary',
+        'category': 'common',
+        'examples': ['Horn Concerto: I. Allegro',
+                     'Die Meistersinger von Nürnberg'],
+        'data_type': 'str',
+    },
+    'ar_combined_year': {
+        'description': 'First “original_year” then “year”.',
+        'category': 'common',
+        'examples': [1978],
+        'data_type': 'int',
+    },
+    'ar_initial_album': {
+        'description': 'First character in lowercase of “ar_combined_album”.',
+        'category': 'common',
+        'examples': ['h'],
+    },
+    'ar_initial_artist': {
+        'description': 'First character in lowercase of '
+                       '“ar_combined_artist_sort”',
+        'category': 'common',
+        'examples': ['b'],
+        'data_type': 'str',
+    },
+    'ar_initial_composer': {
+        'description': 'First character in lowercase of '
+                       '“ar_combined_composer”. '
+                       'For example “Ludwig van Beethoven” -> “l”',
+        'category': 'common',
+        'examples': ['l'],
+        'data_type': 'str',
+    },
+    'ar_performer': {
+        'description': 'Performer names.',
+        'category': 'common',
+        'examples': ['Herbert von Karajan, Staatskapelle Dresden'],
+        'data_type': 'str',
+    },
+    'ar_performer_raw': {
+        'description': 'Raw performer names.',
+        'category': 'common',
+        'examples': [[['conductor', 'Herbert von Karajan'],
+                      ['orchestra', 'Staatskapelle Dresden']]],
+        'data_type': 'list',
+    },
+    'ar_performer_short': {
+        'description': 'Abbreviated performer names.',
+        'category': 'common',
+        'examples': ['Karajan, StaDre'],
+        'data_type': 'str',
     },
 }
 """Documentation of the extra fields."""
 
-all_fields = phrydy.doc.merge_fields(phrydy.doc.fields, fields)
+all_fields = phrydy.merge_fields(phrydy.fields, fields)
 
 
 class ArgsDefault():
@@ -95,6 +155,7 @@ class ArgsDefault():
     best_format = False
     classical = False
     color = False
+    no_color = False
     compilation = False
     copy = False
     debug = False
@@ -102,6 +163,7 @@ class ArgsDefault():
     dry_run = False
     enrich_metadata = False
     extension = 'mp3,m4a,flac,wma'
+    genre_classical = ','
     field_skip = False
     format = False
     job_info = False
@@ -110,9 +172,10 @@ class ArgsDefault():
     no_rename = False
     one_line = False
     remap_classical = False
+    format_classical = False
     shell_friendly = False
     soundtrack = False
-    source = u'.'
+    source = '.'
     source_as_target = False
     stats = False
     target = ''
@@ -136,7 +199,8 @@ def description():
 Metadata fields
 ===============
 
-''' + phrydy.doc.get_doc(additional_doc=fields) + '''
+''' + phrydy.format_fields_as_txt(additional_fields=fields, color=True,
+                                  field_prefix='$') + '''
 
 Functions
 =========
@@ -163,7 +227,7 @@ def parse_args(argv):
 
     parser.add_argument(
         'source',
-        help='A folder containing audio files or a audio file'
+        help='A folder containing audio files or a single audio file'
     )
 
     ##
@@ -239,8 +303,8 @@ def parse_args(argv):
         help='Use the best format. This option only takes effect if the \
         target file already exists. `audiorename` now checks the qualtity of \
         the two audio files (source and target). The tool first examines the \
-        format. For example a flac file wins over a mp3 file. `audiorename`\
-        then checks the bitrate.',
+        format. For example a FLAC file wins over a MP3 file. Then \
+        `audiorename` checks the bitrate.',
         action='store_true'
     )
 
@@ -272,30 +336,35 @@ def parse_args(argv):
     exclusive_rename_move.add_argument(
         '-n',
         '--no-rename',
-        help='Don’t rename, move, copy dry run. Do nothing.',
+        help='Don’t rename, move, copy or perform a dry run. Do nothing.',
         action='store_true'
     )
 
 ##
-# Cleanup actions
+# Cleaning actions
 ##
 
-    rename_cleanup = parser.add_argument_group('rename cleanup actions')
-    exclusive_rename_cleanup = rename_cleanup.add_mutually_exclusive_group()
+    rename_cleaning = parser.add_argument_group(
+        title='rename cleaning actions',
+        description='The cleaning actions are only executed if the target '
+        'file already exists.'
+    )
+    exclusive_rename_cleaning = rename_cleaning.add_mutually_exclusive_group()
 
     # --backup
-    exclusive_rename_cleanup.add_argument(
+    exclusive_rename_cleaning.add_argument(
         '-A',
         '--backup',
-        help='Backup audio files instead of delete files',
+        help='Backup the audio files instead of deleting them. The backup \
+        directory can be specified with the --backup-folder option.',
         action='store_true'
     )
 
     # delete
-    rename.add_argument(
+    exclusive_rename_cleaning.add_argument(
         '-D',
         '--delete',
-        help='Delete files.',
+        help='Delete the audio files instead of creating a backup.',
         action='store_true'
     )
 
@@ -309,7 +378,7 @@ def parse_args(argv):
     filters.add_argument(
         '-F',
         '--album-complete',
-        help='Rename only complete albums',
+        help='Rename only complete albums.',
         action='store_true'
     )
 
@@ -325,10 +394,17 @@ def parse_args(argv):
     filters.add_argument(
         '-e',
         '--extension',
-        help='Extensions to rename',
+        help='Extensions to rename.',
         default='mp3,m4a,flac,wma'
     )
 
+    # genre classical
+    filters.add_argument(
+        '--genre-classical',
+        help='List of genres to be classical.',
+        default=','
+    )
+
 ###############################################################################
 # formats
 ###############################################################################
@@ -389,21 +465,37 @@ def parse_args(argv):
         and functions to build the format string.',
         default=False
     )
-
+    # classical
+    format_strings.add_argument(
+        '--format-classical',
+        metavar='FORMAT_STRING',
+        help='Format string for classical audio file. Use metadata fields \
+        and functions to build the format string.',
+        default=False
+    )
 ###############################################################################
 # output
 ###############################################################################
 
     output = parser.add_argument_group('output')
 
+    output_color = output.add_mutually_exclusive_group()
+
     # color
-    output.add_argument(
+    output_color.add_argument(
         '-K',
         '--color',
         help='Colorize the standard output of the program with ANSI colors.',
         action='store_true'
     )
 
+    output_color.add_argument(
+        '--no-color',
+        help='Don’t colorize the standard output of the program with ANSI '
+             'colors.',
+        action='store_true'
+    )
+
     # debug
     output.add_argument(
         '-b',
