@@ -248,13 +248,14 @@ classical/Mozart_Horn-concertos/01.mp3
 """
 
 from audiorename._version import get_versions
-from phrydy import MediaFile
+from phrydy import MediaFileExtended
 from tmep import Functions
 import musicbrainzngs as mbrainz
 import re
+import typing
 
 
-def set_useragent():
+def set_useragent() -> None:
     mbrainz.set_useragent(
         'audiorename',
         get_versions()['version'],
@@ -262,7 +263,9 @@ def set_useragent():
     )
 
 
-def query_mbrainz(mb_type, mb_id):
+def query_mbrainz(
+        mb_type: typing.Literal['recording', 'work', 'release'],
+        mb_id: str) -> typing.Union[typing.Dict[str, typing.Any], None]:
     method = 'get_' + mb_type + '_by_id'
     query = getattr(mbrainz, method)
 
@@ -281,14 +284,14 @@ def query_mbrainz(mb_type, mb_id):
         return result[mb_type]
 
     except mbrainz.ResponseError as err:
-        if err.cause.code == 404:
+        if err.cause and err.cause.code == 404:
             print('Item of type “' + mb_type + '” with the ID '
                   '“' + mb_id + '” not found.')
         else:
             print("Received bad response from the MusicBrainz server.")
 
 
-def work_recursion(work_id, works=[]):
+def query_works_recursively(work_id: str, works=[]):
     work = query_mbrainz('work', work_id)
 
     if not work:
@@ -306,28 +309,44 @@ def work_recursion(work_id, works=[]):
                 break
 
     if parent_work:
-        work_recursion(parent_work['work']['id'], works)
+        query_works_recursively(parent_work['work']['id'], works)
 
     return works
 
 
-def dict_diff(first, second):
-    """Compare two dicts for differenes.
+def compare_dicts(first: typing.Dict[str, str],
+                  second: typing.Dict[str, str]) -> typing.List[str]:
+    """Compare two dictionaries for differenes.
 
-    :param first: Fist dictionary to diff.
+    :param first: First dictionary to diff.
     :param second: Second dicationary to diff.
-    :return diff: As list of key entries which values differ.
+
+    :return: As list of key entries whose values differ.
     """
     diff = []
-    for key, value in sorted(first.items()):
-        if first[key] != second[key]:
+    for key, _ in sorted(first.items()):
+        if key not in second:
+            diff.append((key, first[key], None))
+
+    for key, _ in sorted(second.items()):
+        if key not in first:
+            diff.append((key, None, second[key]))
+
+    all_keys = set()
+    for key, _ in first.items():
+        all_keys.add(key)
+    for key, _ in second.items():
+        all_keys.add(key)
+    for key in sorted(all_keys):
+        if key in first and key in second and first[key] != second[key]:
             diff.append((key, first[key], second[key]))
+
     return diff
 
 
-class Meta(MediaFile):
+class Meta(MediaFileExtended):
 
-    def __init__(self, path, shell_friendly=False):
+    def __init__(self, path, shell_friendly: bool = False):
         super(Meta, self).__init__(path, False)
         self.shell_friendly = shell_friendly
 
@@ -335,9 +354,12 @@ class Meta(MediaFile):
 # Public methods
 ###############################################################################
 
-    def export_dict(self, sanitize=True):
+    def export_dict(self, sanitize: bool = True) -> typing.Dict[str, str]:
         """
-        :param bool sanitize: Boolean value to trigger the sanitize function.
+        Export all fields into a dictionary.
+
+        :param sanitize: Set the parameter to true to trigger the sanitize
+          function.
         """
         out = {}
         for field in self.fields_sorted():
@@ -347,12 +369,10 @@ class Meta(MediaFile):
                     out[field] = self._sanitize(str(value))
                 else:
                     out[field] = value
-            else:
-                out[field] = u''
 
         return out
 
-    def enrich_metadata(self):
+    def enrich_metadata(self) -> None:
         set_useragent()
 
         if self.mb_trackid:
@@ -361,9 +381,10 @@ class Meta(MediaFile):
             print('No music brainz track id found.')
             return
 
+        release = None
         if self.mb_albumid:
             release = query_mbrainz('release', self.mb_albumid)
-        if 'release-group' in release:
+        if release and 'release-group' in release:
             release_group = release['release-group']
             types = []
             if 'type' in release_group:
@@ -378,13 +399,13 @@ class Meta(MediaFile):
         work_id = ''
         if self.mb_workid:
             work_id = self.mb_workid
-        else:
+        elif recording:
             try:
                 work_id = recording['work-relation-list'][0]['work']['id']
             except KeyError:
                 pass
         if work_id:
-            work_hierarchy = work_recursion(work_id, [])
+            work_hierarchy = query_works_recursively(work_id, [])
             if work_hierarchy:
                 work_hierarchy.reverse()
                 work_bottom = work_hierarchy[-1]
@@ -405,7 +426,7 @@ class Meta(MediaFile):
                 self.work_hierarchy = ' -> '.join(wh_titles)
                 self.mb_workhierarchy_ids = '/'.join(wh_ids)
 
-    def remap_classical(self):
+    def remap_classical(self) -> None:
         """Remap some fields to fit better for classical music. For example
         ``composer`` becomes ``artist`` and ``work`` becomes ``album``.
         All overwritten fields are safed in the ``comments`` field. No
@@ -437,13 +458,13 @@ class Meta(MediaFile):
             self.album = album
 
         if safe:
-            comments = u'Original metadata: '
+            comments = 'Original metadata: '
             for safed in safe:
                 comments = comments + \
-                    str(safed[0]) + u': ' + \
-                    str(safed[1]) + u'; '
+                    str(safed[0]) + ': ' + \
+                    str(safed[1]) + '; '
 
-        self.comments = comments
+            self.comments = comments
 
 ###############################################################################
 # Class methods
@@ -451,7 +472,7 @@ class Meta(MediaFile):
 
     @classmethod
     def fields_phrydy(cls):
-        for field in sorted(MediaFile.readable_fields()):
+        for field in sorted(MediaFileExtended.readable_fields()):
             yield field
 
     @classmethod
@@ -482,35 +503,36 @@ class Meta(MediaFile):
 ###############################################################################
 
     @staticmethod
-    def _initials(value):
+    def _initials(value: str) -> str:
         """
         :param str value: A string to extract the initials.
         """
         return value[0:1].lower()
 
     @staticmethod
-    def _normalize_performer(ar_performer):
+    def _normalize_performer(
+            ar_performer: typing.List[str]) -> typing.List[typing.List[str]]:
         """
         :param list ar_performer: A list of raw ar_performer strings like
 
         .. code-block:: python
 
-            [u'John Lennon (vocals)', u'Ringo Starr (drums)']
+            ['John Lennon (vocals)', 'Ringo Starr (drums)']
 
         :return: A list
 
         .. code-block:: python
 
             [
-                ['vocals', u'John Lennon'],
-                ['drums', u'Ringo Starr'],
+                ['vocals', 'John Lennon'],
+                ['drums', 'Ringo Starr'],
             ]
         """
         out = []
         if isinstance(ar_performer, list):
             for value in ar_performer:
                 value = value[:-1]
-                value = value.split(u' (')
+                value = value.split(' (')
                 if isinstance(value, list) and len(value) == 2:
                     out.append([value[1], value[0]])
             return out
@@ -518,7 +540,7 @@ class Meta(MediaFile):
             return []
 
     @staticmethod
-    def _roman_to_int(n):
+    def _roman_to_int(n: str) -> int:
         numeral_map = tuple(zip(
             (1000, 900, 500, 400, 100, 90, 50, 40, 10, 9, 5, 4, 1),
             ('M', 'CM', 'D', 'CD', 'C', 'XC', 'L', 'XL', 'X', 'IX', 'V', 'IV',
@@ -532,18 +554,19 @@ class Meta(MediaFile):
         return result
 
     @staticmethod
-    def _sanitize(value):
+    def _sanitize(value) -> str:
         if isinstance(value, str) or isinstance(value, bytes):
             value = Functions.tmpl_sanitize(value)
-            value = re.sub(r'\s{2,}', ' ', value)
+            value = re.sub(r'\s{2,}', ' ', str(value))
         else:
-            value = u''
+            value = ''
         return value
 
     @staticmethod
-    def _shorten_performer(ar_performer, length=3, separator=u' ',
-                           abbreviation=u'.'):
-        out = u''
+    def _shorten_performer(ar_performer: str, length: int = 3,
+                           separator: str = ' ',
+                           abbreviation: str = '.') -> str:
+        out = ''
         count = 0
         for s in ar_performer.split(' '):
             if count < 3:
@@ -568,7 +591,7 @@ class Meta(MediaFile):
 ###############################################################################
 
     @property
-    def ar_classical_album(self):
+    def ar_classical_album(self) -> typing.Optional[str]:
         """Uses:
 
         * ``phrydy.mediafile.MediaFile.work``
@@ -580,11 +603,9 @@ class Meta(MediaFile):
         """
         if self.work:
             return re.sub(r':.*$', '', (str(self.work)))
-        else:
-            return u''
 
     @property
-    def ar_combined_album(self):
+    def ar_combined_album(self) -> typing.Optional[str]:
         """Uses:
 
         * ``phrydy.mediafile.MediaFile.album``
@@ -595,11 +616,9 @@ class Meta(MediaFile):
         """
         if self.album:
             return re.sub(r' ?\([dD]is[ck].*\)$', '', str(self.album))
-        else:
-            return u''
 
     @property
-    def ar_initial_album(self):
+    def ar_initial_album(self) -> typing.Optional[str]:
         """Uses:
 
         * :class:`audiorename.meta.Meta.ar_combined_album`
@@ -609,7 +628,8 @@ class Meta(MediaFile):
         * ``Just Friends`` → ``j``
         * ``Die Meistersinger von Nürnberg``  → ``d``
         """
-        return self._initials(self.ar_combined_album)
+        if self.ar_combined_album:
+            return self._initials(self.ar_combined_album)
 
     @property
     def ar_initial_artist(self):
@@ -625,7 +645,7 @@ class Meta(MediaFile):
         return self._initials(self.ar_combined_artist_sort)
 
     @property
-    def ar_combined_artist(self):
+    def ar_combined_artist(self) -> str:
         """Uses:
 
         * ``phrydy.mediafile.MediaFile.albumartist``
@@ -649,12 +669,12 @@ class Meta(MediaFile):
         elif self.artist_sort:
             out = self.artist_sort
         else:
-            out = u'Unknown'
+            out = 'Unknown'
 
         return out
 
     @property
-    def ar_combined_artist_sort(self):
+    def ar_combined_artist_sort(self) -> str:
         """Uses:
 
         * ``phrydy.mediafile.MediaFile.albumartist_sort``
@@ -679,7 +699,7 @@ class Meta(MediaFile):
         elif self.artist_credit:
             out = self.artist_credit
         else:
-            out = u'Unknown'
+            out = 'Unknown'
 
         if self.shell_friendly:
             out = out.replace(', ', '_')
@@ -687,7 +707,7 @@ class Meta(MediaFile):
         return out
 
     @property
-    def ar_initial_composer(self):
+    def ar_initial_composer(self) -> str:
         """Uses:
 
         * :class:`audiorename.meta.Meta.ar_combined_composer`
@@ -695,7 +715,7 @@ class Meta(MediaFile):
         return self._initials(self.ar_combined_composer)
 
     @property
-    def ar_combined_composer(self):
+    def ar_combined_composer(self) -> str:
         """Uses:
 
         * ``phrydy.mediafile.MediaFile.composer_sort``
@@ -716,7 +736,7 @@ class Meta(MediaFile):
         return re.sub(r' ?/.*', '', out)
 
     @property
-    def ar_combined_disctrack(self):
+    def ar_combined_disctrack(self) -> typing.Optional[str]:
         """
         Generate a combination of track and disc number, e. g.: ``1-04``,
         ``3-06``.
@@ -730,7 +750,7 @@ class Meta(MediaFile):
         """
 
         if not self.track:
-            return ''
+            return
 
         if self.disctotal and int(self.disctotal) > 99:
             disk = str(self.disc).zfill(3)
@@ -759,9 +779,9 @@ class Meta(MediaFile):
 
         * :class:`audiorename.meta.Meta.ar_performer_raw`
         """
-        out = u''
+        out = ''
         for ar_performer in self.ar_performer_raw:
-            out = out + u', ' + ar_performer[1]
+            out = out + ', ' + ar_performer[1]
 
         out = out[2:]
 
@@ -781,7 +801,7 @@ class Meta(MediaFile):
         elif self.albumartist:
             out = re.sub(r'^.*; ?', '', self.albumartist)
         else:
-            out = u''
+            out = ''
 
         return out
 
@@ -797,8 +817,8 @@ class Meta(MediaFile):
         .. code-block:: python
 
             [
-                ['conductor', u'Herbert von Karajan'],
-                ['violin', u'Anne-Sophie Mutter'],
+                ['conductor', 'Herbert von Karajan'],
+                ['violin', 'Anne-Sophie Mutter'],
             ]
 
         Uses:
@@ -811,7 +831,7 @@ class Meta(MediaFile):
                 'performer' in self.mgfile:
             out = self._normalize_performer(self.mgfile['performer'])
             if 'conductor' in self.mgfile:
-                out.insert(0, [u'conductor', self.mgfile['conductor'][0]])
+                out.insert(0, ['conductor', self.mgfile['conductor'][0]])
         elif self.format == 'MP3':
             # 4.2.2 TMCL Musician credits list
             if 'TMCL' in self.mgfile:
@@ -824,7 +844,7 @@ class Meta(MediaFile):
             # 4.2.2 TPE3 Conductor/ar_performer refinement
             if len(out) > 0 and 'conductor' not in out[0] \
                     and 'TPE3' in self.mgfile:
-                out.insert(0, [u'conductor', self.mgfile['TPE3'].text[0]])
+                out.insert(0, ['conductor', self.mgfile['TPE3'].text[0]])
 
         else:
             out = []
@@ -842,7 +862,7 @@ class Meta(MediaFile):
         performers = self.ar_performer_raw
         picked = []
         for performer in performers:
-            if performer[0] == u'conductor' or performer[0] == u'orchestra':
+            if performer[0] == 'conductor' or performer[0] == 'orchestra':
                 picked.append(performer)
 
         if len(picked) > 0:
@@ -850,31 +870,31 @@ class Meta(MediaFile):
 
         for performer in performers:
 
-            if performer[0] == u'producer' or \
-                    performer[0] == u'executive producer' or \
+            if performer[0] == 'producer' or \
+                    performer[0] == 'executive producer' or \
                     performer[0] == 'balance engineer':
                 pass
-            elif performer[0] == u'orchestra' or \
-                    performer[0] == u'choir vocals' or \
+            elif performer[0] == 'orchestra' or \
+                    performer[0] == 'choir vocals' or \
                     performer[0] == 'string quartet':
-                out.append(self._shorten_performer(performer[1], separator=u'',
-                                                   abbreviation=u''))
+                out.append(self._shorten_performer(performer[1], separator='',
+                                                   abbreviation=''))
             else:
                 out.append(performer[1].split(' ')[-1])
 
-        return u', '.join(out)
+        return ', '.join(out)
 
     @property
     def ar_combined_soundtrack(self):
-        if (self.releasegroup_types and u'soundtrack'
+        if (self.releasegroup_types and 'soundtrack'
            in self.releasegroup_types.lower()) or \
-           (self.albumtype and u'soundtrack' in self.albumtype.lower()):
+           (self.albumtype and 'soundtrack' in self.albumtype.lower()):
             return True
         else:
             return False
 
     @property
-    def ar_classical_title(self):
+    def ar_classical_title(self) -> typing.Optional[str]:
         """Uses:
 
         * ``phrydy.mediafile.MediaFile.title``
@@ -885,28 +905,24 @@ class Meta(MediaFile):
         """
         if self.title:
             return re.sub(r'^[^:]*: ?', '', self.title)
-        else:
-            return u''
 
     @property
-    def ar_classical_track(self):
+    def ar_classical_track(self) -> typing.Optional[str]:
         """Uses:
 
         * :class:`audiorename.meta.Meta.ar_classical_title`
         * :class:`audiorename.meta.Meta.ar_combined_disctrack`
         """
-        roman = re.findall(r'^([IVXLCDM]*)\.', self.ar_classical_title)
+        roman = None
+        if self.ar_classical_title:
+            roman = re.findall(r'^([IVXLCDM]*)\.', self.ar_classical_title)
         if roman:
-            out = str(self._roman_to_int(roman[0])).zfill(2)
+            return str(self._roman_to_int(roman[0])).zfill(2)
         elif self.ar_combined_disctrack:
-            out = self.ar_combined_disctrack
-        else:
-            out = ''
-
-        return out
+            return self.ar_combined_disctrack
 
     @property
-    def ar_combined_work_top(self):
+    def ar_combined_work_top(self) -> typing.Optional[str]:
         """Uses:
 
         * ``phrydy.mediafile.MediaFile.work_hierarchy``
